define(
//begin v1.x content
{
	"field-tue-relative+-1": "el martes pasado",
	"field-year": "año",
	"field-wed-relative+0": "este miércoles",
	"field-wed-relative+1": "el próximo miércoles",
	"timeFormat-short": "H:mm",
	"field-minute": "minuto",
	"field-month-narrow-relative+-1": "el mes pasado",
	"field-tue-narrow-relative+0": "este MA",
	"field-tue-narrow-relative+1": "el próximo MA",
	"field-thu-short-relative+0": "este jue.",
	"field-day-short-relative+-1": "ayer",
	"field-thu-short-relative+1": "el próximo jue.",
	"field-day-relative+0": "hoy",
	"field-day-short-relative+-2": "anteayer",
	"field-day-relative+1": "mañana",
	"field-week-narrow-relative+0": "esta sem.",
	"field-day-relative+2": "pasado mañana",
	"field-week-narrow-relative+1": "próx. sem.",
	"field-wed-narrow-relative+-1": "el MI pasado",
	"field-year-narrow": "a",
	"field-era-short": "era",
	"field-year-narrow-relative+0": "este año",
	"field-tue-relative+0": "este martes",
	"field-year-narrow-relative+1": "el próximo año",
	"field-tue-relative+1": "el próximo martes",
	"field-weekdayOfMonth": "día de la semana del mes",
	"field-second-short": "s",
	"dayPeriods-format-narrow-am": "a. m.",
	"dateFormatItem-MMMd": "d MMM",
	"field-weekdayOfMonth-narrow": "día de sem. de mes",
	"dayPeriods-format-abbr-am": "a. m.",
	"field-week-relative+0": "esta semana",
	"field-month-relative+0": "este mes",
	"field-week-relative+1": "la próxima semana",
	"field-month-relative+1": "el próximo mes",
	"field-sun-narrow-relative+0": "este DO",
	"timeFormat-medium": "H:mm:ss",
	"field-mon-short-relative+0": "este lun.",
	"field-sun-narrow-relative+1": "el próximo DO",
	"field-mon-short-relative+1": "el próximo lun.",
	"field-second-relative+0": "ahora",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"months-standAlone-narrow": [
		"E",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"eraNames": [
		"BE"
	],
	"field-weekOfMonth": "semana del mes",
	"dayPeriods-standAlone-abbr-pm": "p. m.",
	"field-month-short": "m",
	"dateFormatItem-GyMMMEd": "E, d MMM y G",
	"dateFormatItem-yyyyMd": "d/M/y GGGGG",
	"field-day": "día",
	"field-dayOfYear-short": "día del a",
	"field-year-relative+-1": "el año pasado",
	"dayPeriods-format-wide-am": "a. m.",
	"field-sat-short-relative+-1": "el sáb. pasado",
	"field-hour-relative+0": "esta hora",
	"dateFormatItem-yyyyMEd": "E, d/M/y GGGGG",
	"field-wed-relative+-1": "el miércoles pasado",
	"field-sat-narrow-relative+-1": "el SA pasado",
	"field-second": "segundo",
	"days-standAlone-narrow": [
		"D",
		"L",
		"M",
		"X",
		"J",
		"V",
		"S"
	],
	"dayPeriods-standAlone-wide-pm": "p. m.",
	"dateFormat-long": "d 'de' MMMM 'de' y G",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-quarter": "trimestre",
	"field-week-short": "sem.",
	"field-day-narrow-relative+0": "hoy",
	"field-day-narrow-relative+1": "mañana",
	"field-day-narrow-relative+2": "pasado mañana",
	"quarters-standAlone-wide": [
		"1.er trimestre",
		"2.º trimestre",
		"3.er trimestre",
		"4.º trimestre"
	],
	"days-format-narrow": [
		"D",
		"L",
		"M",
		"X",
		"J",
		"V",
		"S"
	],
	"field-tue-short-relative+0": "este mar.",
	"field-tue-short-relative+1": "el próximo mar.",
	"field-month-short-relative+-1": "el mes pasado",
	"field-mon-relative+-1": "el lunes pasado",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "mes",
	"field-day-narrow": "d",
	"field-minute-short": "min",
	"field-dayperiod": "a. m./p. m.",
	"field-sat-short-relative+0": "este sáb.",
	"field-sat-short-relative+1": "el próximo sáb.",
	"dayPeriods-format-narrow-pm": "p. m.",
	"dateFormat-medium": "d/M/y G",
	"dateFormatItem-yyyyMMMM": "MMMM 'de' y G",
	"eraAbbr": [
		"BE"
	],
	"quarters-standAlone-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"dayPeriods-format-abbr-pm": "p. m.",
	"dateFormatItem-yyyyM": "M/y GGGGG",
	"field-second-narrow": "s",
	"field-mon-relative+0": "este lunes",
	"field-mon-relative+1": "el próximo lunes",
	"field-day-narrow-relative+-1": "ayer",
	"field-year-short": "a",
	"field-day-narrow-relative+-2": "anteayer",
	"months-format-narrow": [
		"E",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-quarter-relative+-1": "el trimestre pasado",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"field-dayperiod-narrow": "a. m./p. m.",
	"dayPeriods-standAlone-narrow-am": "a. m.",
	"field-week-narrow-relative+-1": "sem. ant.",
	"days-format-short": [
		"DO",
		"LU",
		"MA",
		"MI",
		"JU",
		"VI",
		"SA"
	],
	"dayPeriods-format-wide-pm": "p. m.",
	"field-dayOfYear": "día del año",
	"field-sat-relative+-1": "el sábado pasado",
	"dateTimeFormat-long": "{1}, {0}",
	"dateFormatItem-Md": "d/M",
	"field-hour": "hora",
	"months-format-wide": [
		"enero",
		"febrero",
		"marzo",
		"abril",
		"mayo",
		"junio",
		"julio",
		"agosto",
		"septiembre",
		"octubre",
		"noviembre",
		"diciembre"
	],
	"dateFormat-full": "EEEE, d 'de' MMMM 'de' y G",
	"field-month-relative+-1": "el mes pasado",
	"field-quarter-short": "trim.",
	"field-sat-narrow-relative+0": "este SA",
	"field-fri-relative+0": "este viernes",
	"field-sat-narrow-relative+1": "el próximo SA",
	"field-fri-relative+1": "el próximo viernes",
	"field-month-narrow-relative+0": "este mes",
	"field-month-narrow-relative+1": "el próximo mes",
	"field-sun-short-relative+0": "este dom.",
	"field-sun-short-relative+1": "el próximo dom.",
	"field-week-relative+-1": "la semana pasada",
	"months-format-abbr": [
		"ene",
		"feb",
		"mar",
		"abr",
		"may",
		"jun",
		"jul",
		"ago",
		"sept",
		"oct",
		"nov",
		"dic"
	],
	"field-quarter-relative+0": "este trimestre",
	"field-minute-relative+0": "este minuto",
	"timeFormat-long": "H:mm:ss z",
	"field-quarter-relative+1": "el próximo trimestre",
	"field-wed-short-relative+-1": "el mié. pasado",
	"dateFormat-short": "d/M/yy G",
	"field-thu-short-relative+-1": "el jue. pasado",
	"field-year-narrow-relative+-1": "el año pasado",
	"days-standAlone-wide": [
		"domingo",
		"lunes",
		"martes",
		"miércoles",
		"jueves",
		"viernes",
		"sábado"
	],
	"dateFormatItem-yyyyMMMEd": "EEE, d MMM y G",
	"field-mon-narrow-relative+-1": "el LU pasado",
	"dateFormatItem-MMMMd": "d 'de' MMMM",
	"field-thu-narrow-relative+-1": "el JU pasado",
	"field-tue-narrow-relative+-1": "el MA pasado",
	"field-weekOfMonth-short": "sem. de mes",
	"dateFormatItem-yyyy": "y G",
	"dayPeriods-standAlone-narrow-pm": "p. m.",
	"field-wed-short-relative+0": "este mié.",
	"months-standAlone-wide": [
		"enero",
		"febrero",
		"marzo",
		"abril",
		"mayo",
		"junio",
		"julio",
		"agosto",
		"septiembre",
		"octubre",
		"noviembre",
		"diciembre"
	],
	"field-wed-short-relative+1": "el próximo mié.",
	"field-sun-relative+-1": "el domingo pasado",
	"days-standAlone-abbr": [
		"dom",
		"lun",
		"mar",
		"mié",
		"jue",
		"vie",
		"sáb"
	],
	"dateTimeFormat-full": "{1}, {0}",
	"field-weekday": "día de la semana",
	"field-day-short-relative+0": "hoy",
	"field-sat-relative+0": "este sábado",
	"field-day-short-relative+1": "mañana",
	"field-sat-relative+1": "el próximo sábado",
	"field-day-short-relative+2": "pasado mañana",
	"field-week-short-relative+0": "esta sem.",
	"field-week-short-relative+1": "próx. sem.",
	"months-standAlone-abbr": [
		"ene",
		"feb",
		"mar",
		"abr",
		"may",
		"jun",
		"jul",
		"ago",
		"sept",
		"oct",
		"nov",
		"dic"
	],
	"field-dayOfYear-narrow": "día del a",
	"field-month-short-relative+0": "este mes",
	"field-month-short-relative+1": "el próximo mes",
	"field-weekdayOfMonth-short": "día de sem. de mes",
	"timeFormat-full": "H:mm:ss (zzzz)",
	"dateFormatItem-MEd": "E, d/M",
	"field-zone-narrow": "zona",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "este JU",
	"field-thu-narrow-relative+1": "el próximo JU",
	"field-sun-narrow-relative+-1": "el DO pasado",
	"field-mon-short-relative+-1": "el lun. pasado",
	"field-thu-relative+0": "este jueves",
	"field-thu-relative+1": "el próximo jueves",
	"field-fri-short-relative+-1": "el vie. pasado",
	"field-thu-relative+-1": "el jueves pasado",
	"field-week": "semana",
	"quarters-format-wide": [
		"1.er trimestre",
		"2.º trimestre",
		"3.er trimestre",
		"4.º trimestre"
	],
	"dateFormatItem-Ed": "E d",
	"field-wed-narrow-relative+0": "este MI",
	"field-wed-narrow-relative+1": "el próximo MI",
	"field-year-short-relative+0": "este año",
	"field-dayperiod-short": "a. m./p. m.",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"field-year-short-relative+1": "el próximo año",
	"field-fri-short-relative+0": "este vie.",
	"field-fri-short-relative+1": "el próximo vie.",
	"days-standAlone-short": [
		"DO",
		"LU",
		"MA",
		"MI",
		"JU",
		"VI",
		"SA"
	],
	"field-week-short-relative+-1": "sem. ant.",
	"dateFormatItem-yyyyQQQQ": "QQQQ 'de' y G",
	"field-hour-short": "h",
	"field-zone-short": "zona",
	"quarters-format-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"field-month-narrow": "m",
	"field-hour-narrow": "h",
	"field-fri-narrow-relative+-1": "el VI pasado",
	"field-year-relative+0": "este año",
	"field-year-relative+1": "el próximo año",
	"field-era-narrow": "era",
	"field-fri-relative+-1": "el viernes pasado",
	"eraNarrow": "BE",
	"field-tue-short-relative+-1": "el mar. pasado",
	"field-minute-narrow": "min",
	"days-format-wide": [
		"domingo",
		"lunes",
		"martes",
		"miércoles",
		"jueves",
		"viernes",
		"sábado"
	],
	"field-mon-narrow-relative+0": "este LU",
	"field-mon-narrow-relative+1": "el próximo LU",
	"field-year-short-relative+-1": "el año pasado",
	"field-zone": "zona horaria",
	"dateFormatItem-MMMEd": "E, d MMM",
	"field-weekOfMonth-narrow": "sem. de mes",
	"field-weekday-narrow": "día de sem.",
	"field-quarter-narrow": "trim.",
	"field-sun-short-relative+-1": "el dom. pasado",
	"field-day-relative+-1": "ayer",
	"dayPeriods-standAlone-abbr-am": "a. m.",
	"field-day-relative+-2": "anteayer",
	"field-weekday-short": "día de sem.",
	"days-format-abbr": [
		"dom",
		"lun",
		"mar",
		"mié",
		"jue",
		"vie",
		"sáb"
	],
	"field-sun-relative+0": "este domingo",
	"field-sun-relative+1": "el próximo domingo",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "d",
	"field-week-narrow": "sem.",
	"field-era": "era",
	"field-fri-narrow-relative+0": "este VI",
	"field-fri-narrow-relative+1": "el próximo VI",
	"dayPeriods-standAlone-wide-am": "a. m."
}
//end v1.x content
);